Package 'demographr'

Title: R package for mapping UK demographics
Description: A package to distribute UK demographic data.
Authors: Mike Page [cre], Matt Thomas [aut], Aileen McDonald [aut], British Red Cross [cph]
Maintainer: Mike Page <[email protected]>
License: MIT + file LICENSE
Version: 0.0.1
Built: 2026-05-31 08:35:25 UTC
Source: https://github.com/humaniverse/demographr

Help Index


Age and gender grouped data for Northern Ireland from Population 2020 (Health and Social Care Trusts)

Description

A dataset containing Population 2020 age and gender count for each HSCT in Northern Ireland.

Usage

age_gender_hsct20_ni

Format

A data frame of class "tbl" with 5 rows and 11 variables:

hsct20_name

Health and Social Care Trust name

hsct20_code

Health and Social Care Trust code

total_population

Total population

total_female_population

Total female population

total_male_population

Total male population

younger_females

Count of females aged under 16 years

working_age_females

Count of females aged between 16 and 65

older_females

Count of females aged over 65

younger_males

Count of males aged under 16 years

working_age_males

Count of males aged between 16 and 65

older_males

Count of males aged over 65

https://www.nisra.gov.uk/


Age and gender grouped data for Northern Ireland from 2021 Census (Local Government Districts)

Description

A dataset containing Census 2021 age and gender count for each Local Government District in Northern Ireland.

Usage

age_gender_ltla21_ni

Format

A data frame of class "tbl" with 11 rows and 11 variables:

ltla21_name

Local Government District name

ltla21_code

Local Government District code

total_population

Total population

total_female_population

Total female population

total_male_population

Total male population

younger_females

Count of females aged under 20 years

working_age_females

Count of females aged between 20 and 65

older_females

Count of females aged over 65

younger_males

Count of males aged under 20 years

working_age_males

Count of males aged between 20 and 65

older_males

Count of males aged over 65

https://www.nisra.gov.uk/


Age and gender grouped data for England and Wales from 2021 Census

Description

A dataset containing Census 2021 age and gender count for each LA in England and Wales

Usage

age_gender21_ltla21_ew

Format

A data frame of class "tbl" with 11 rows and 11 variables:

ltla21_code

Local Authority code

total_population

Total population

total_female_population

Total female population

total_male_population

Total male population

younger_females

Count of females aged under 20 years

working_age_females

Count of females aged between 20 and 65

older_females

Count of females aged over 65

younger_males

Count of males aged under 20 years

working_age_males

Count of males aged between 20 and 65

older_males

Count of males aged over 65

https://www.nomisweb.co.uk/sources/census_2021_bulk


Age and gender grouped data for Northern Ireland from 2023 Mid Year Estimates (Local Government Districts)

Description

A dataset containing 2023 mid year estimates age and gender count for each Local Government District in Northern Ireland.

Usage

age_gender23_ltla_ni

Format

A data frame of class "tbl" with 11 rows and 11 variables:

ltla21_name

Local Government District name (2014). Renamed LTLA for consistency.

ltla21_code

Local Government District code (2014). Renamed LTLA for consistency.

total_population

Total population

total_female_population

Total female population

total_male_population

Total male population

younger_females

Count of females aged under 16 years

working_age_females

Count of females aged between 16 and 64

older_females

Count of females aged over 64

younger_males

Count of males aged under 16 years

working_age_males

Count of males aged between 16 and 64

older_males

Count of males aged over 64

https://www.nisra.gov.uk/


Disability data for Northern Ireland from the 2021 Census (LGD)

Description

A data LSOA containing Census 2021 disability numbers and percentages for each LTLA in England and Wales.

Usage

disability21_lgd21_ni

Format

A data frame of class "tbl":

lgd21_code

LGD code

disability

Disability status

count

The count of people with the disability status

prop

The percentage of people with the disability status

...

https://www.nisra.gov.uk/


Disability data for England and Wales from the 2021 Census (Lower Super Output Area)

Description

A dataset containing Census 2021 disability numbers and percentages for each LSOA in England and Wales.

Usage

disability21_lsoa21_ew

Format

A data frame of class "tbl":

lsoa21_code

LSOA code

disability

Disability status

n

The count of people with the disability status

total_residents

Total residents in LSOA

prop

The percentage of people with the disability status

...

https://www.nomisweb.co.uk/sources/census_2021_bulk


Disability data for Northern Ireland from the 2021 Census (Super Data Zones)

Description

A data SDZ containing Census 2021 disability numbers and percentages for each SDZ in Northern Ireland.

Usage

disability21_sdz21_ni

Format

A data frame of class "tbl":

sdz21_code

SDZ code

total_households

Total number of households in each SDZ

disability

Disability status

n

The count of households with the disability status

prop

The percentage of households with the disability status

...

https://www.nisra.gov.uk/


Disability data for Scotland from the 2022 Census (Data Zones)

Description

A data DZ containing Census 2022 disability numbers and percentages for each DZ in Scotland.

Usage

disability22_dz11_scot

Format

A data frame of class "tbl":

dz11_code

DZ code

total_residents

Total number of residents in each DZ

disability

Disability status

n

The count of residents with the disability status

prop

The percentage of residents with the disability status

...

https://www.nisra.gov.uk/


Ethnic group (detailed) data for England and Wales from the 2021 Census (MSOA)

Description

A data sets containing Census 2021 detailed ethnic group numbers and percentages for each Middle Layer Super Output Area in England and Wales.

Usage

ethnicity21_detailed_msoa21

Format

A data frame of class "tbl" with 2,084,768 rows and 5 variables:

msoa21_code

MSOA code

total_residents

Total number of residents in the MSOA

ethnic_group

Ethnic group (detailed)

n

Number of people in the ethnic group

prop

Percentage of people in the ethnic group

...

https://ons.gov.uk/


Ethnic group data for England and Wales from the 2021 Census (LSOA)

Description

A data sets containing Census 2021 ethnic group numbers and percentages for each Lower Layer Super Output Area in England and Wales.

Usage

ethnicity21_lsoa21

Format

A data frame of class "tbl" with 5 variables:

mloa21_code

LSOA code

total_residents

Total number of residents in the LSOA

ethnic_group

Ethnic group

n

Number of people in the ethnic group

prop

Percentage of people in the ethnic group

...

https://ons.gov.uk/


Ethnic group data for England and Wales from the 2021 Census (Local Authority)

Description

A data sets containing Census 2021 ethnic group numbers and percentages for each Lower Tier Local Authority in England and Wales.

Usage

ethnicity21_ltla21

Format

A data frame of class "tbl" with 12578 rows and 4 variables:

ltla21_name

Local Authority name

ltla21_code

Local Authority code

ethnic_group

Ethnic group

value

The count or percentage of the ethnic group

...

https://ons.gov.uk/


Ethnic group data for Northern Ireland from the 2021 Census (Local Authority)

Description

A data sets containing Census 2021 ethnic group numbers and percentages for each Local Government District in Northern Ireland.

Usage

ethnicity21_ltla21_ni

Format

A data frame of class "tbl" with 286 rows and 4 variables:

ltla21_name

Local Authority name

ltla21_code

Local Authority code

ethnic_group

Ethnic group

value

The count or percentage of the ethnic group

...

https://www.nisra.gov.uk/


Ethnic group data for England and Wales from the 2021 Census (MSOA)

Description

A data sets containing Census 2021 ethnic group numbers and percentages for each Middle Layer Super Output Area in England and Wales.

Usage

ethnicity21_msoa21

Format

A data frame of class "tbl" with 43,584 rows and 5 variables:

msoa21_code

MSOA code

total_residents

Total number of residents in the MSOA

ethnic_group

Ethnic group

n

Number of people in the ethnic group

prop

Percentage of people in the ethnic group

...

https://ons.gov.uk/


Deprivation dimensions for Data Zones in Scotland

Description

A data set containing 2011 estimates of deprivation dimensions for Data Zones in Scotland.

Usage

household_deprivation11_dz11

Format

A data frame of class "tbl" with 34,880 rows and 5 variables:

dz11_code

Data Zone code

total_households

Total number of households in each DZ

deprivation_dimensions

Deprived in dimensions (0 to 4)

n

Number of households per each deprivation dimension

prop

The percentage of households with the deprivation dimension status

https://www.scotlandscensus.gov.uk/search-the-census


Deprivation dimensions for Lower Super Output Areas in England and Wales

Description

A data set containing 2021 estimates of deprivation dimensions for Lower Super Output Areas in England and Wales.

Usage

household_deprivation21_lsoa21

Format

A data frame of class "tbl" with 178,360 rows and 5 variables:

lsoa21_code

Lower Super Output Area code

total_households

Total number of households in each LSOA

deprivation_dimensions

Deprived in dimensions (0 to 4)

n

Number of households per each deprivation dimension

prop

The percentage of households with the deprivation dimension status

https://www.nomisweb.co.uk/sources/census_2021_bulk


Deprivation dimensions for Output Areas in England and Wales

Description

A data set containing 2021 estimates of deprivation dimensions for Output Areas in England and Wales.

Usage

household_deprivation21_oa21

Format

A data frame of class "tbl" with 944,400 rows and 5 variables:

oa21_code

Output Area code

total_households

Total number of households in each OA

deprivation_dimensions

Deprived in dimensions (0 to 4)

n

Number of households per each deprivation dimension

prop

The percentage of households with the deprivation dimension status

https://www.nomisweb.co.uk/sources/census_2021_bulk


Deprivation dimensions for Super Data Zones in Northern Ireland

Description

A data set containing 2021 estimates of deprivation dimensions for Super Data Zones in Northern Ireland.

Usage

household_deprivation21_sdz21

Format

A data frame of class "tbl" with 4,250 rows and 5 variables:

sdz21_code

Super Data Zone code

total_households

Total number of households in each SDZ

deprivation_dimensions

Deprived in dimensions (0 to 4)

n

Number of households per each deprivation dimension

prop

The percentage of households with the deprivation dimension status

https://www.nisra.gov.uk/


Household overcrowding statistics for Lower Super Output Areas in England and Wales

Description

A data set containing 2021 estimates of household overcrowding for Lower Super Output Areas in England and Wales.

Usage

household_overcrowding21_lsoa21

Format

A data frame of class "tbl" with 178,360 rows and 5 variables:

lsoa21_code

Lower Super Output Area code

total_households

Total number of households in each LSOA

occupancy_rating

Occupancy rating

n

Number of households per each occupancy rating

prop

The percentage of households with the specific occupancy rating

https://www.nomisweb.co.uk/sources/census_2021_bulk


Household overcrowding statistics for Output Areas in England and Wales

Description

A data set containing 2021 estimates of household overcrowding for Output Areas in England and Wales.

Usage

household_overcrowding21_oa21

Format

A data frame of class "tbl" with 994,440 rows and 5 variables:

oa21_code

Lower Super Output Area code

total_households

Total number of households in each OA

occupancy_rating

Occupancy rating

n

Number of households per each occupancy rating

prop

The percentage of households with the specific occupancy rating

https://www.nomisweb.co.uk/sources/census_2021_bulk


Household overcrowding statistics for Super Data Zones in Northern Ireland

Description

A data set containing 2021 estimates of household overcrowding for Super Data Zones in Northern Ireland.

Usage

household_overcrowding21_sdz21

Format

A data frame of class "tbl" with 4,250 rows and 5 variables:

sdz21_code

Super Data Zone code

total_households

Total number of households in each SDZ

occupancy_rating

Occupancy rating

n

Number of households per each occupancy rating

prop

The percentage of households with the specific occupancy rating

https://www.nisra.gov.uk/


Household overcrowding statistics for Data Zones in Scotland

Description

A data set containing 2022 estimates of household overcrowding for Data Zones in Scotland.

Usage

household_overcrowding22_dz11

Format

A data frame of class "tbl" with 27,904 rows and 5 variables:

dz11_code

Data Zone code

total_households

Total number of households in each DZ

occupancy_rating

Occupancy rating

n

Number of households per each occupancy rating

prop

The percentage of households with the specific occupancy rating

https://www.scotlandscensus.gov.uk/scotlands-census-2022-flexible-table-builder/


Household tenure statistics for Lower Super Output Areas in England and Wales

Description

A data set containing 2021 estimates of household tenure for Lower Super Output Areas in England and Wales.

Usage

household_tenure21_lsoa21

Format

A data frame of class "tbl" with 285,376 rows and 5 variables:

lsoa21_code

Lower Super Output Area code

total_households

Total number of households in each LSOA

tenure

Household tenure type

n

Number of households per each tenure type

prop

The percentage of households with the specific tenure type

https://www.nomisweb.co.uk/sources/census_2021_bulk


Household tenure statistics for Output Areas in England and Wales

Description

A data set containing 2021 estimates of household tenure for Output Areas in England and Wales.

Usage

household_tenure21_oa21

Format

A data frame of class "tbl" with 1,511,040 rows and 5 variables:

oa21_code

Output Area code

total_households

Total number of households in each OA

tenure

Household tenure type

n

Number of households per each tenure type

prop

The percentage of households with the specific tenure type

https://www.nomisweb.co.uk/sources/census_2021_bulk


Household tenure statistics for Super Data Zones in Northern Ireland

Description

A data set containing 2021 estimates of household tenure for Super Data Zones in Northern Ireland.

Usage

household_tenure21_sdz21

Format

A data frame of class "tbl" with 9,350 rows and 5 variables:

sdz21_code

Super Data Zone code

total_households

Total number of households in each SDZ

tenure

Household tenure type

n

Number of households per each tenure type

prop

The percentage of households with the specific tenure type

https://www.nisra.gov.uk/


Household tenure statistics for Data Zones in Scotland

Description

A data set containing 2022 estimates of household tenure for Data Zones in Scotland.

Usage

household_tenure22_dz11

Format

A data frame of class "tbl" with 55,808 rows and 5 variables:

dz11_code

Data Zone code

total_households

Total number of households in each DZ

tenure

Household tenure type

n

Number of households per each tenure type

prop

The percentage of households with the specific tenure type

https://www.scotlandscensus.gov.uk/scotlands-census-2022-flexible-table-builder/


Household type statistics for Lower Super Output Areas in England and Wales

Description

A data set containing 2021 estimates of household type for Lower Super Output Areas in England and Wales.

Usage

household_type21_lsoa21

Format

A data frame of class "tbl" with 285,376 rows and 5 variables:

lsoa21_code

Lower Super Output Area code

total_households

Total number of households in each LSOA

type

Household type

n

Number of households per each household type

prop

The percentage of households with the specific household type

https://www.nomisweb.co.uk/sources/census_2021_bulk


Household type statistics for Output Areas in England and Wales

Description

A data set containing 2021 estimates of household type for Output Areas in England and Wales.

Usage

household_type21_oa21

Format

A data frame of class "tbl" with 1,511,040 rows and 5 variables:

oa21_code

Output Area code

total_households

Total number of households in each OA

type

Household type

n

Number of households per each household type

prop

The percentage of households with the specific household type

https://www.nomisweb.co.uk/sources/census_2021_bulk


Household type statistics for Super Data Zones in Northern Ireland

Description

A data set containing 2021 estimates of household type for Super Data Zones in Northern Ireland.

Usage

household_type21_sdz21

Format

A data frame of class "tbl" with 5,950 rows and 5 variables:

sdz21_code

Super Data Zone code

total_households

Total number of households in each SDZ

type

Household type

n

Number of households per each household type

prop

The percentage of households with the specific household type

https://www.nisra.gov.uk/


Household type statistics for Data Zones in Scotland

Description

A data set containing 2022 estimates of household type for Data Zones in Scotland.

Usage

household_type22_dz11

Format

A data frame of class "tbl" with 48,832 rows and 5 variables:

dz11_code

Data Zone code

total_households

Total number of households in each DZ

type

Household type

n

Number of households per each household type

prop

The percentage of households with the specific household type

https://www.scotlandscensus.gov.uk/scotlands-census-2022-flexible-table-builder/


Households in Lower Tier Local Authorities in England and Wales, as of Census 2021

Description

A data sets containing Census 2021 population counts for each Lower Tier Local Authority in the UK. Currently only Local Authority data has been released for England and Wales.

Usage

households21_ltla21

Format

A data frame of class "tbl" with 331 rows and 3 variables:

ltla21_name

Local Authority name

ltla21_code

Local Authority code

households

Number of households

...

https://ons.gov.uk/


A data sets containing Census 2021 migration statistics with percentages for each Middle Super Output Area (MSOA).

Description

A data sets containing Census 2021 migration statistics with percentages for each Middle Super Output Area (MSOA).

Usage

migration21_msoa21

Format

A data frame of class "tbl" with 7264 rows and 9 variables:

msoa21_code

MSOA code

msoa21_name

MSOA name

all_usual_residents

Number of all usual residents

address_one_year_ago_is_the_same

Number where address one year ago is the same as the address of enumeration

address_one_year_ago_is_student_or_boarding

Number where address one year ago is student term-time or boarding school address in the UK

migrant_from_within_uk

Migrant from within the UK: Number where address one year ago was in the UK

migrant_from_outside_uk

Migrant from outside the UK: Number where address one year ago was outside the UK

prop_migrated_from_within_uk

Proportion of migrants from within the UK

prop_migrated_from_outside_uk

Proportion of migrants from outside the UK

...

https://www.nomisweb.co.uk/sources/census_2021_bulk


Scottish Health Board (2019) Population Estimates

Description

A data set containing population estimates for NHS Scotland Health Boards (2019), from 1981 to 2021.

Usage

population_hb19

Format

A data frame of class "tbl" with 574 rows and 3 variables:

hb19_code

NHS Health Board code

year

Year of population estimate

total_population

Total population for all ages

...

https://www.opendata.nhs.scot/


Population estimates for LSOAs in England and Wales (mid-2017 estimates with 2011 codes)

Description

A data set containing mid-2017 population estimates for Lower Layer Super Output Areas in England and Wales.

Usage

population17_lsoa11

Format

A data frame of class "tbl" with 34,753 rows and 94 variables:

lsoa11_name

LSOA name

lsoa11_code

LSOA code

total_population

Total number of people living in each LSOA

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for LSOAs in England and Wales (mid-2019 estimates with 2011 codes)

Description

A data set containing mid-2019 population estimates for Lower Layer Super Output Areas in England and Wales.

Usage

population19_lsoa11

Format

A data frame of class "tbl" with 34,753 rows and 94 variables:

lsoa11_name

LSOA name

lsoa11_code

LSOA code

total_population

Total number of people living in each LSOA

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for Local Authority Districts (mid-2019 values with 2019 codes)

Description

A data set containing mid-2019 population estimates for Local Authority Districts (April 2019 codes) in each devolved nation.

Usage

population19_ltla19

Format

A data frame of class "tbl" with 339 rows and 94 variables:

ltla19_name

LAD name

ltla19_code

LAD code

total_population

Total number of people living in each LAD

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for Local Authority Districts (mid-2019 values with 2020 codes)

Description

A data set containing mid-2019 population estimates for Local Authority Districts (April 2020 codes) in each devolved nation.

Usage

population19_ltla20

Format

A data frame of class "tbl" with 336 rows and 94 variables:

ltla20_name

LAD name

ltla20_code

LAD code

total_population

Total number of people living in each LAD

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for MSOAs in England and Wales (mid-2019 estimates with 2011 codes)

Description

A data set containing mid-2019 population estimates for Middle Layer Super Output Areas in England and Wales.

Usage

population19_msoa11

Format

A data frame of class "tbl" with 7,201 rows and 94 variables:

msoa11_name

MSOA name

msoa11_code

MSOA code

total_population

Total number of people living in each MSOA

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for Counties and Unitary Authorities (mid-2019 values with 2019 codes)

Description

A data set containing mid-2019 population estimates for County and Unitary Authority Districts (April 2019 codes) in each devolved nation.

Usage

population19_utla19

Format

A data frame of class "tbl" with 173 rows and 94 variables:

utla19_name

County or Unitary Authority name

utla19_code

County or Unitary Authority code

total_population

Total number of people living in each area

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for Counties and Unitary Authorities (mid-2019 values with 2020 codes)

Description

A data set containing mid-2019 population estimates for County and Unitary Authority Districts (April 2020 codes) in each devolved nation.

Usage

population19_utla20

Format

A data frame of class "tbl" with 173 rows and 94 variables:

utla20_name

County or Unitary Authority name

utla20_code

County or Unitary Authority code

total_population

Total number of people living in each area

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for Data Zones in Scotland (2020 estimates with 2011 codes)

Description

A data set containing 2020 population estimates by age and sex for Data Zones in Scotland.

Usage

population20_dz11

Format

A data frame of class "tbl" with 20,928 rows and 94 variables:

dz11_code

Data Zone code

total_population

Total number of people living in each DZ

sex

'Female', 'Male' or 'All'

0:⁠90+⁠

Number of people in each single age group

...

https://www.opendata.nhs.scot/


Population estimates for LSOAs in England and Wales (mid-2020 estimates with 2011 codes)

Description

A data set containing mid-2020 population estimates for Lower Layer Super Output Areas in England and Wales.

Usage

population20_lsoa11

Format

A data frame of class "tbl" with 34,753 rows and 94 variables:

lsoa11_name

LSOA name

lsoa11_code

LSOA code

total_population

Total number of people living in each LSOA

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for Local Authority Districts (mid-2020 values with 2020 codes)

Description

A data set containing mid-2020 population estimates for Local Authority Districts (April 2020 codes) in each devolved nation.

Usage

population20_ltla20

Format

A data frame of class "tbl" with 336 rows and 94 variables:

ltla20_name

LAD name

ltla20_code

LAD code

total_population

Total number of people living in each LAD

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for Local Authority Districts (mid-2020 values with 2021 codes)

Description

A data set containing mid-2020 population estimates for Local Authority Districts (April 2021 codes) in each devolved nation.

Usage

population20_ltla21

Format

A data frame of class "tbl" with 331 rows and 94 variables:

ltla21_name

LAD name

ltla21_code

LAD code

total_population

Total number of people living in each LAD

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for MSOAs in England and Wales (mid-2020 estimates with 2011 codes)

Description

A data set containing mid-2020 population estimates for Middle Layer Super Output Areas in England and Wales.

Usage

population20_msoa11

Format

A data frame of class "tbl" with 7,201 rows and 94 variables:

msoa11_name

MSOA name

msoa11_code

MSOA code

total_population

Total number of people living in each MSOA

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for OAs in England and Wales (mid-2020 estimates with 2011 codes)

Description

A data set containing mid-2020 population estimates for Output Areas in England and Wales.

Usage

population20_oa11

Format

A data frame of class "tbl" with 181,408 rows and 94 variables:

oa11_name

OA name

oa11_code

OA code

total_population

Total number of people living in each OA

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population estimates for Counties and Unitary Authorities (mid-2020 values with 2020 codes)

Description

A data set containing mid-2020 population estimates for County and Unitary Authority Districts (April 2020 codes) in each devolved nation.

Usage

population20_utla20

Format

A data frame of class "tbl" with 172 rows and 94 variables:

utla20_name

County or Unitary Authority name

utla20_code

County or Unitary Authority code

total_population

Total number of people living in each area

0:⁠90+⁠

Number of people in each single age group

...

https://ons.gov.uk/


Population in UK countries, as of Census 2021

Description

A data sets containing Census 2021 population counts for each UK nation. Note that Scotland has not yet released its latest Census results, so this is based on mid-year population estimates.

Usage

population21_country21

Format

A data frame of class "tbl" with 4 rows and 3 variables:

country_name

Country name

country_code

Country code

population

Number of people

...

https://ons.gov.uk/


Usual Resident Population, District Electoral Area, Northern Ireland, based on Census 2021

Description

Usual Resident Population, District Electoral Area, Northern Ireland, based on Census 2021

Usage

population21_dea14

Format

A data frame of class "tbl" with 80 rows and 3 variables:

dea14_name

District Electoral Area name

dea14_code

District Electoral Area code

residents

All usual residents

...

https://www.nisra.gov.uk/publications/census-2021-person-and-household-estimates-data-zones-northern-ireland


Population estimates in Scotland's Data Zones (2011 codes), as of 2021

Description

Population estimates in Scotland's Data Zones (2011 codes), as of 2021

Usage

population21_dz11

Format

A data frame of class "tbl" with 6,976 rows and 3 variables:

dz11_name

Data Zone name

dz11_code

Data Zone code

total_population

Number of people

...

https://statistics.gov.scot/


Population estimates in Scotland's Intermediate Zones (2011 codes), as of 2021

Description

Population estimates in Scotland's Intermediate Zones (2011 codes), as of 2021

Usage

population21_iz11

Format

A data frame of class "tbl" with 1,279 rows and 3 variables:

iz11_name

Intermediate Zone name

iz11_code

Intermediate Zone code

total_population

Number of people

...

https://statistics.gov.scot/


Usual Resident Population, Local Government District, Northern Ireland, based on Census 2021

Description

Usual Resident Population, Local Government District, Northern Ireland, based on Census 2021

Usage

population21_lgd14

Format

A data frame of class "tbl" with 11 rows and 3 variables:

lgd14_name

Local Government District name

lgd14_code

Local Government District code

residents

All usual residents

...

https://www.nisra.gov.uk/publications/census-2021-person-and-household-estimates-data-zones-northern-ireland


Population in UK Lower Tier Local Authorities, as of Census 2021

Description

A data sets containing Census 2021 population counts for each Lower Tier Local Authority in the UK. Currently only Local Authority data has been released for England and Wales.

Usage

population21_ltla21

population21_ltla21

Format

A data frame of class "tbl" with 331 rows and 3 variables:

ltla21_name

Local Authority name

ltla21_code

Local Authority code

population

Number of people

...

A data frame of class "tbl" with 32 rows and 3 variables:

ltla21_name

Intermediate Zone name

ltla21_code

Intermediate Zone code

total_population

Number of people

...

https://ons.gov.uk/

https://statistics.gov.scot/


Usual Resident Population, Super Data Zone, Northern Ireland, based on Census 2021

Description

Usual Resident Population, Super Data Zone, Northern Ireland, based on Census 2021

Usage

population21_sdz21

Format

A data frame of class "tbl" with 850 rows and 3 variables:

sdz21_name

Super Data Zone name

sdz21_code

Super Data Zone code

residents

All usual residents

...

https://www.nisra.gov.uk/publications/census-2021-person-and-household-estimates-data-zones-northern-ireland


Population in England and Wales Lower Layer Super Output Areas, 2022 mid year estimates

Description

Population in England and Wales Lower Layer Super Output Areas, 2022 mid year estimates

Usage

population22_lsoa21

Format

A data frame of class "tbl" with 25,672 rows and 2 variables:

lsoa21_code

LSOA code

n_people

Estimated number of people in LSOA

...

https://ons.gov.uk


Population in Scotland Councils, 2022 mid year estimates

Description

A data set containing 2022 mid year estimate population counts for each Council in Scotland by sex, age.

Usage

population22_ltla19_scotland

Format

A data frame of class "tbl" with 32 rows and 95 variables:

ltla19_name

Local Authority name

ltla19_code

Local Authority code

sex

Sex

all_ages

Total number of people

0:⁠90 and over⁠

Number of people in each single age group

...

https://www.nrscotland.gov.uk/statistics-and-data/statistics/statistics-by-theme/population/population-estimates/mid-year-population-estimates/mid-2022#:~:text=Of%20the%2032%20council%20areas,and%20Orkney%20Islands%20with%2022%2C020)


Proficiency in English for England and Wales from the 2021 Census (MSOA)

Description

A data sets containing Census 2021 proficiency in English numbers and percentages for each Middle Layer Super Output Area in England and Wales.

Usage

proficiency21_msoa21

Format

A data frame of class "tbl" with 7,264 rows and 8 variables:

msoa21_code

MSOA code

Main language is English (English or Welsh in Wales)

Number of residents where main language is English (English or Welsh in Wales)

Main language is not English (English or Welsh in Wales)

Number of residents where main language is not English (English or Welsh in Wales)

Main language is not English (English or Welsh in Wales): Can speak English very well

Number of residents where main language is not English (English or Welsh in Wales): Can speak English very wel

Main language is not English (English or Welsh in Wales): Can speak English well

Number of residents where main language is not English (English or Welsh in Wales): Can speak English wel

Main language is not English (English or Welsh in Wales): Cannot speak English well

Number of residents where main language is not English (English or Welsh in Wales): Cannot speak English wel

Main language is not English (English or Welsh in Wales): Cannot speak English

Number of residents where main language is not English (English or Welsh in Wales): Cannot speak Englishwel

...

https://ons.gov.uk/


Religion data for England and Wales from the 2021 Census (MSOA)

Description

A data sets containing Census 2021 religion numbers and percentages for each Lower Layer Super Output Area in England and Wales.

A data sets containing Census 2021 religion numbers and percentages for each Local Government District in Northern Ireland.

Usage

religion21_lsoa21

religion21_lsoa21

Format

A data frame of class "tbl" with 5 variables:

lsoa21_code

LSOA code

total_residents

Total number of residents in the LSOA

religion

Religion

n

Number of people in the religion

prop

Percentage of people in the religion

...

A data frame of class "tbl" with 5 variables:

lgd21_code

LGD code

religion

Religion

count

Number of people

prop

Percentage of people

...

https://ons.gov.uk/

https://www.nisra.gov.uk/


Religion data for NI from the 2021 Census (LGD)

Description

A data sets containing Census 2021 sexual orientation numbers and percentages for each Local Government District in Northern Ireland.

Usage

sexualorientation21_lgd21_ni

Format

A data frame of class "tbl" with 4 variables:

lgd21_code

LGD code

sexual_orientation

Sexual Orientation

count

Number of people

prop

Percentage of people

...

https://www.nisra.gov.uk/


Religion data for England and Wales from the 2021 Census (MSOA)

Description

A data sets containing Census 2021 sexual orientation numbers and percentages for each MSOA in England and Wales

Usage

sexualorientation21_msoa21_ew

Format

A data frame of class "tbl" with 4 variables:

msoa21_code

MSOA code

sexual_orientation

Sexual Orientation

count

Number of people

prop

Percentage of people

...

https://ons.gov.uk/