| Title: | R package for mapping UK demographics |
|---|---|
| Description: | A package to distribute UK demographic data. |
| Authors: | Mike Page [cre], Matt Thomas [aut], Aileen McDonald [aut], British Red Cross [cph] |
| Maintainer: | Mike Page <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.0.1 |
| Built: | 2026-05-31 08:35:25 UTC |
| Source: | https://github.com/humaniverse/demographr |
A dataset containing Population 2020 age and gender count for each HSCT in Northern Ireland.
age_gender_hsct20_niage_gender_hsct20_ni
A data frame of class "tbl" with 5 rows and 11 variables:
Health and Social Care Trust name
Health and Social Care Trust code
Total population
Total female population
Total male population
Count of females aged under 16 years
Count of females aged between 16 and 65
Count of females aged over 65
Count of males aged under 16 years
Count of males aged between 16 and 65
Count of males aged over 65
A dataset containing Census 2021 age and gender count for each Local Government District in Northern Ireland.
age_gender_ltla21_niage_gender_ltla21_ni
A data frame of class "tbl" with 11 rows and 11 variables:
Local Government District name
Local Government District code
Total population
Total female population
Total male population
Count of females aged under 20 years
Count of females aged between 20 and 65
Count of females aged over 65
Count of males aged under 20 years
Count of males aged between 20 and 65
Count of males aged over 65
A dataset containing Census 2021 age and gender count for each LA in England and Wales
age_gender21_ltla21_ewage_gender21_ltla21_ew
A data frame of class "tbl" with 11 rows and 11 variables:
Local Authority code
Total population
Total female population
Total male population
Count of females aged under 20 years
Count of females aged between 20 and 65
Count of females aged over 65
Count of males aged under 20 years
Count of males aged between 20 and 65
Count of males aged over 65
https://www.nomisweb.co.uk/sources/census_2021_bulk
A dataset containing 2023 mid year estimates age and gender count for each Local Government District in Northern Ireland.
age_gender23_ltla_niage_gender23_ltla_ni
A data frame of class "tbl" with 11 rows and 11 variables:
Local Government District name (2014). Renamed LTLA for consistency.
Local Government District code (2014). Renamed LTLA for consistency.
Total population
Total female population
Total male population
Count of females aged under 16 years
Count of females aged between 16 and 64
Count of females aged over 64
Count of males aged under 16 years
Count of males aged between 16 and 64
Count of males aged over 64
A data LSOA containing Census 2021 disability numbers and percentages for each LTLA in England and Wales.
disability21_lgd21_nidisability21_lgd21_ni
A data frame of class "tbl":
LGD code
Disability status
The count of people with the disability status
The percentage of people with the disability status
...
A dataset containing Census 2021 disability numbers and percentages for each LSOA in England and Wales.
disability21_lsoa21_ewdisability21_lsoa21_ew
A data frame of class "tbl":
LSOA code
Disability status
The count of people with the disability status
Total residents in LSOA
The percentage of people with the disability status
...
https://www.nomisweb.co.uk/sources/census_2021_bulk
A data SDZ containing Census 2021 disability numbers and percentages for each SDZ in Northern Ireland.
disability21_sdz21_nidisability21_sdz21_ni
A data frame of class "tbl":
SDZ code
Total number of households in each SDZ
Disability status
The count of households with the disability status
The percentage of households with the disability status
...
A data DZ containing Census 2022 disability numbers and percentages for each DZ in Scotland.
disability22_dz11_scotdisability22_dz11_scot
A data frame of class "tbl":
DZ code
Total number of residents in each DZ
Disability status
The count of residents with the disability status
The percentage of residents with the disability status
...
A data sets containing Census 2021 detailed ethnic group numbers and percentages for each Middle Layer Super Output Area in England and Wales.
ethnicity21_detailed_msoa21ethnicity21_detailed_msoa21
A data frame of class "tbl" with 2,084,768 rows and 5 variables:
MSOA code
Total number of residents in the MSOA
Ethnic group (detailed)
Number of people in the ethnic group
Percentage of people in the ethnic group
...
A data sets containing Census 2021 ethnic group numbers and percentages for each Lower Layer Super Output Area in England and Wales.
ethnicity21_lsoa21ethnicity21_lsoa21
A data frame of class "tbl" with 5 variables:
LSOA code
Total number of residents in the LSOA
Ethnic group
Number of people in the ethnic group
Percentage of people in the ethnic group
...
A data sets containing Census 2021 ethnic group numbers and percentages for each Lower Tier Local Authority in England and Wales.
ethnicity21_ltla21ethnicity21_ltla21
A data frame of class "tbl" with 12578 rows and 4 variables:
Local Authority name
Local Authority code
Ethnic group
The count or percentage of the ethnic group
...
A data sets containing Census 2021 ethnic group numbers and percentages for each Local Government District in Northern Ireland.
ethnicity21_ltla21_niethnicity21_ltla21_ni
A data frame of class "tbl" with 286 rows and 4 variables:
Local Authority name
Local Authority code
Ethnic group
The count or percentage of the ethnic group
...
A data sets containing Census 2021 ethnic group numbers and percentages for each Middle Layer Super Output Area in England and Wales.
ethnicity21_msoa21ethnicity21_msoa21
A data frame of class "tbl" with 43,584 rows and 5 variables:
MSOA code
Total number of residents in the MSOA
Ethnic group
Number of people in the ethnic group
Percentage of people in the ethnic group
...
A data set containing 2011 estimates of deprivation dimensions for Data Zones in Scotland.
household_deprivation11_dz11household_deprivation11_dz11
A data frame of class "tbl" with 34,880 rows and 5 variables:
Data Zone code
Total number of households in each DZ
Deprived in dimensions (0 to 4)
Number of households per each deprivation dimension
The percentage of households with the deprivation dimension status
https://www.scotlandscensus.gov.uk/search-the-census
A data set containing 2021 estimates of deprivation dimensions for Lower Super Output Areas in England and Wales.
household_deprivation21_lsoa21household_deprivation21_lsoa21
A data frame of class "tbl" with 178,360 rows and 5 variables:
Lower Super Output Area code
Total number of households in each LSOA
Deprived in dimensions (0 to 4)
Number of households per each deprivation dimension
The percentage of households with the deprivation dimension status
https://www.nomisweb.co.uk/sources/census_2021_bulk
A data set containing 2021 estimates of deprivation dimensions for Output Areas in England and Wales.
household_deprivation21_oa21household_deprivation21_oa21
A data frame of class "tbl" with 944,400 rows and 5 variables:
Output Area code
Total number of households in each OA
Deprived in dimensions (0 to 4)
Number of households per each deprivation dimension
The percentage of households with the deprivation dimension status
https://www.nomisweb.co.uk/sources/census_2021_bulk
A data set containing 2021 estimates of deprivation dimensions for Super Data Zones in Northern Ireland.
household_deprivation21_sdz21household_deprivation21_sdz21
A data frame of class "tbl" with 4,250 rows and 5 variables:
Super Data Zone code
Total number of households in each SDZ
Deprived in dimensions (0 to 4)
Number of households per each deprivation dimension
The percentage of households with the deprivation dimension status
A data set containing 2021 estimates of household overcrowding for Lower Super Output Areas in England and Wales.
household_overcrowding21_lsoa21household_overcrowding21_lsoa21
A data frame of class "tbl" with 178,360 rows and 5 variables:
Lower Super Output Area code
Total number of households in each LSOA
Occupancy rating
Number of households per each occupancy rating
The percentage of households with the specific occupancy rating
https://www.nomisweb.co.uk/sources/census_2021_bulk
A data set containing 2021 estimates of household overcrowding for Output Areas in England and Wales.
household_overcrowding21_oa21household_overcrowding21_oa21
A data frame of class "tbl" with 994,440 rows and 5 variables:
Lower Super Output Area code
Total number of households in each OA
Occupancy rating
Number of households per each occupancy rating
The percentage of households with the specific occupancy rating
https://www.nomisweb.co.uk/sources/census_2021_bulk
A data set containing 2021 estimates of household overcrowding for Super Data Zones in Northern Ireland.
household_overcrowding21_sdz21household_overcrowding21_sdz21
A data frame of class "tbl" with 4,250 rows and 5 variables:
Super Data Zone code
Total number of households in each SDZ
Occupancy rating
Number of households per each occupancy rating
The percentage of households with the specific occupancy rating
A data set containing 2022 estimates of household overcrowding for Data Zones in Scotland.
household_overcrowding22_dz11household_overcrowding22_dz11
A data frame of class "tbl" with 27,904 rows and 5 variables:
Data Zone code
Total number of households in each DZ
Occupancy rating
Number of households per each occupancy rating
The percentage of households with the specific occupancy rating
https://www.scotlandscensus.gov.uk/scotlands-census-2022-flexible-table-builder/
A data set containing 2021 estimates of household tenure for Lower Super Output Areas in England and Wales.
household_tenure21_lsoa21household_tenure21_lsoa21
A data frame of class "tbl" with 285,376 rows and 5 variables:
Lower Super Output Area code
Total number of households in each LSOA
Household tenure type
Number of households per each tenure type
The percentage of households with the specific tenure type
https://www.nomisweb.co.uk/sources/census_2021_bulk
A data set containing 2021 estimates of household tenure for Output Areas in England and Wales.
household_tenure21_oa21household_tenure21_oa21
A data frame of class "tbl" with 1,511,040 rows and 5 variables:
Output Area code
Total number of households in each OA
Household tenure type
Number of households per each tenure type
The percentage of households with the specific tenure type
https://www.nomisweb.co.uk/sources/census_2021_bulk
A data set containing 2021 estimates of household tenure for Super Data Zones in Northern Ireland.
household_tenure21_sdz21household_tenure21_sdz21
A data frame of class "tbl" with 9,350 rows and 5 variables:
Super Data Zone code
Total number of households in each SDZ
Household tenure type
Number of households per each tenure type
The percentage of households with the specific tenure type
A data set containing 2022 estimates of household tenure for Data Zones in Scotland.
household_tenure22_dz11household_tenure22_dz11
A data frame of class "tbl" with 55,808 rows and 5 variables:
Data Zone code
Total number of households in each DZ
Household tenure type
Number of households per each tenure type
The percentage of households with the specific tenure type
https://www.scotlandscensus.gov.uk/scotlands-census-2022-flexible-table-builder/
A data set containing 2021 estimates of household type for Lower Super Output Areas in England and Wales.
household_type21_lsoa21household_type21_lsoa21
A data frame of class "tbl" with 285,376 rows and 5 variables:
Lower Super Output Area code
Total number of households in each LSOA
Household type
Number of households per each household type
The percentage of households with the specific household type
https://www.nomisweb.co.uk/sources/census_2021_bulk
A data set containing 2021 estimates of household type for Output Areas in England and Wales.
household_type21_oa21household_type21_oa21
A data frame of class "tbl" with 1,511,040 rows and 5 variables:
Output Area code
Total number of households in each OA
Household type
Number of households per each household type
The percentage of households with the specific household type
https://www.nomisweb.co.uk/sources/census_2021_bulk
A data set containing 2021 estimates of household type for Super Data Zones in Northern Ireland.
household_type21_sdz21household_type21_sdz21
A data frame of class "tbl" with 5,950 rows and 5 variables:
Super Data Zone code
Total number of households in each SDZ
Household type
Number of households per each household type
The percentage of households with the specific household type
A data set containing 2022 estimates of household type for Data Zones in Scotland.
household_type22_dz11household_type22_dz11
A data frame of class "tbl" with 48,832 rows and 5 variables:
Data Zone code
Total number of households in each DZ
Household type
Number of households per each household type
The percentage of households with the specific household type
https://www.scotlandscensus.gov.uk/scotlands-census-2022-flexible-table-builder/
A data sets containing Census 2021 population counts for each Lower Tier Local Authority in the UK. Currently only Local Authority data has been released for England and Wales.
households21_ltla21households21_ltla21
A data frame of class "tbl" with 331 rows and 3 variables:
Local Authority name
Local Authority code
Number of households
...
A data sets containing Census 2021 migration statistics with percentages for each Middle Super Output Area (MSOA).
migration21_msoa21migration21_msoa21
A data frame of class "tbl" with 7264 rows and 9 variables:
MSOA code
MSOA name
Number of all usual residents
Number where address one year ago is the same as the address of enumeration
Number where address one year ago is student term-time or boarding school address in the UK
Migrant from within the UK: Number where address one year ago was in the UK
Migrant from outside the UK: Number where address one year ago was outside the UK
Proportion of migrants from within the UK
Proportion of migrants from outside the UK
...
https://www.nomisweb.co.uk/sources/census_2021_bulk
A data set containing population estimates for NHS Scotland Health Boards (2019), from 1981 to 2021.
population_hb19population_hb19
A data frame of class "tbl" with 574 rows and 3 variables:
NHS Health Board code
Year of population estimate
Total population for all ages
...
https://www.opendata.nhs.scot/
A data set containing mid-2017 population estimates for Lower Layer Super Output Areas in England and Wales.
population17_lsoa11population17_lsoa11
A data frame of class "tbl" with 34,753 rows and 94 variables:
LSOA name
LSOA code
Total number of people living in each LSOA
0:90+
Number of people in each single age group
...
A data set containing mid-2019 population estimates for Lower Layer Super Output Areas in England and Wales.
population19_lsoa11population19_lsoa11
A data frame of class "tbl" with 34,753 rows and 94 variables:
LSOA name
LSOA code
Total number of people living in each LSOA
0:90+
Number of people in each single age group
...
A data set containing mid-2019 population estimates for Local Authority Districts (April 2019 codes) in each devolved nation.
population19_ltla19population19_ltla19
A data frame of class "tbl" with 339 rows and 94 variables:
LAD name
LAD code
Total number of people living in each LAD
0:90+
Number of people in each single age group
...
A data set containing mid-2019 population estimates for Local Authority Districts (April 2020 codes) in each devolved nation.
population19_ltla20population19_ltla20
A data frame of class "tbl" with 336 rows and 94 variables:
LAD name
LAD code
Total number of people living in each LAD
0:90+
Number of people in each single age group
...
A data set containing mid-2019 population estimates for Middle Layer Super Output Areas in England and Wales.
population19_msoa11population19_msoa11
A data frame of class "tbl" with 7,201 rows and 94 variables:
MSOA name
MSOA code
Total number of people living in each MSOA
0:90+
Number of people in each single age group
...
A data set containing mid-2019 population estimates for County and Unitary Authority Districts (April 2019 codes) in each devolved nation.
population19_utla19population19_utla19
A data frame of class "tbl" with 173 rows and 94 variables:
County or Unitary Authority name
County or Unitary Authority code
Total number of people living in each area
0:90+
Number of people in each single age group
...
A data set containing mid-2019 population estimates for County and Unitary Authority Districts (April 2020 codes) in each devolved nation.
population19_utla20population19_utla20
A data frame of class "tbl" with 173 rows and 94 variables:
County or Unitary Authority name
County or Unitary Authority code
Total number of people living in each area
0:90+
Number of people in each single age group
...
A data set containing 2020 population estimates by age and sex for Data Zones in Scotland.
population20_dz11population20_dz11
A data frame of class "tbl" with 20,928 rows and 94 variables:
Data Zone code
Total number of people living in each DZ
'Female', 'Male' or 'All'
0:90+
Number of people in each single age group
...
https://www.opendata.nhs.scot/
A data set containing mid-2020 population estimates for Lower Layer Super Output Areas in England and Wales.
population20_lsoa11population20_lsoa11
A data frame of class "tbl" with 34,753 rows and 94 variables:
LSOA name
LSOA code
Total number of people living in each LSOA
0:90+
Number of people in each single age group
...
A data set containing mid-2020 population estimates for Local Authority Districts (April 2020 codes) in each devolved nation.
population20_ltla20population20_ltla20
A data frame of class "tbl" with 336 rows and 94 variables:
LAD name
LAD code
Total number of people living in each LAD
0:90+
Number of people in each single age group
...
A data set containing mid-2020 population estimates for Local Authority Districts (April 2021 codes) in each devolved nation.
population20_ltla21population20_ltla21
A data frame of class "tbl" with 331 rows and 94 variables:
LAD name
LAD code
Total number of people living in each LAD
0:90+
Number of people in each single age group
...
A data set containing mid-2020 population estimates for Middle Layer Super Output Areas in England and Wales.
population20_msoa11population20_msoa11
A data frame of class "tbl" with 7,201 rows and 94 variables:
MSOA name
MSOA code
Total number of people living in each MSOA
0:90+
Number of people in each single age group
...
A data set containing mid-2020 population estimates for Output Areas in England and Wales.
population20_oa11population20_oa11
A data frame of class "tbl" with 181,408 rows and 94 variables:
OA name
OA code
Total number of people living in each OA
0:90+
Number of people in each single age group
...
A data set containing mid-2020 population estimates for County and Unitary Authority Districts (April 2020 codes) in each devolved nation.
population20_utla20population20_utla20
A data frame of class "tbl" with 172 rows and 94 variables:
County or Unitary Authority name
County or Unitary Authority code
Total number of people living in each area
0:90+
Number of people in each single age group
...
A data sets containing Census 2021 population counts for each UK nation. Note that Scotland has not yet released its latest Census results, so this is based on mid-year population estimates.
population21_country21population21_country21
A data frame of class "tbl" with 4 rows and 3 variables:
Country name
Country code
Number of people
...
Usual Resident Population, District Electoral Area, Northern Ireland, based on Census 2021
population21_dea14population21_dea14
A data frame of class "tbl" with 80 rows and 3 variables:
District Electoral Area name
District Electoral Area code
All usual residents
...
Population estimates in Scotland's Data Zones (2011 codes), as of 2021
population21_dz11population21_dz11
A data frame of class "tbl" with 6,976 rows and 3 variables:
Data Zone name
Data Zone code
Number of people
...
Population estimates in Scotland's Intermediate Zones (2011 codes), as of 2021
population21_iz11population21_iz11
A data frame of class "tbl" with 1,279 rows and 3 variables:
Intermediate Zone name
Intermediate Zone code
Number of people
...
Usual Resident Population, Local Government District, Northern Ireland, based on Census 2021
population21_lgd14population21_lgd14
A data frame of class "tbl" with 11 rows and 3 variables:
Local Government District name
Local Government District code
All usual residents
...
A data sets containing Census 2021 population counts for each Lower Tier Local Authority in the UK. Currently only Local Authority data has been released for England and Wales.
population21_ltla21 population21_ltla21population21_ltla21 population21_ltla21
A data frame of class "tbl" with 331 rows and 3 variables:
Local Authority name
Local Authority code
Number of people
...
A data frame of class "tbl" with 32 rows and 3 variables:
Intermediate Zone name
Intermediate Zone code
Number of people
...
Usual Resident Population, Super Data Zone, Northern Ireland, based on Census 2021
population21_sdz21population21_sdz21
A data frame of class "tbl" with 850 rows and 3 variables:
Super Data Zone name
Super Data Zone code
All usual residents
...
Population in England and Wales Lower Layer Super Output Areas, 2022 mid year estimates
population22_lsoa21population22_lsoa21
A data frame of class "tbl" with 25,672 rows and 2 variables:
LSOA code
Estimated number of people in LSOA
...
A data set containing 2022 mid year estimate population counts for each Council in Scotland by sex, age.
population22_ltla19_scotlandpopulation22_ltla19_scotland
A data frame of class "tbl" with 32 rows and 95 variables:
Local Authority name
Local Authority code
Sex
Total number of people
0:90 and over
Number of people in each single age group
...
A data sets containing Census 2021 proficiency in English numbers and percentages for each Middle Layer Super Output Area in England and Wales.
proficiency21_msoa21proficiency21_msoa21
A data frame of class "tbl" with 7,264 rows and 8 variables:
MSOA code
Number of residents where main language is English (English or Welsh in Wales)
Number of residents where main language is not English (English or Welsh in Wales)
Number of residents where main language is not English (English or Welsh in Wales): Can speak English very wel
Number of residents where main language is not English (English or Welsh in Wales): Can speak English wel
Number of residents where main language is not English (English or Welsh in Wales): Cannot speak English wel
Number of residents where main language is not English (English or Welsh in Wales): Cannot speak Englishwel
...
A data sets containing Census 2021 religion numbers and percentages for each Lower Layer Super Output Area in England and Wales.
A data sets containing Census 2021 religion numbers and percentages for each Local Government District in Northern Ireland.
religion21_lsoa21 religion21_lsoa21religion21_lsoa21 religion21_lsoa21
A data frame of class "tbl" with 5 variables:
LSOA code
Total number of residents in the LSOA
Religion
Number of people in the religion
Percentage of people in the religion
...
A data frame of class "tbl" with 5 variables:
LGD code
Religion
Number of people
Percentage of people
...
A data sets containing Census 2021 sexual orientation numbers and percentages for each Local Government District in Northern Ireland.
sexualorientation21_lgd21_nisexualorientation21_lgd21_ni
A data frame of class "tbl" with 4 variables:
LGD code
Sexual Orientation
Number of people
Percentage of people
...
A data sets containing Census 2021 sexual orientation numbers and percentages for each MSOA in England and Wales
sexualorientation21_msoa21_ewsexualorientation21_msoa21_ew
A data frame of class "tbl" with 4 variables:
MSOA code
Sexual Orientation
Number of people
Percentage of people
...